@@ -1,13 +1,10 @@
 """Tests for `ged2doc.cli` module."""
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import pytest
-import shutil
 import tempfile
 
-from ged2doc.cli import _makeWriter
+from ged2doc.cli import main
 from ged2doc.utils import languages
 from ged2doc.i18n import DATE_FORMATS
 
@@ -18,19 +15,12 @@ def data_folder():
     return os.path.join(tests, "data")
 
 
-@pytest.fixture
-def tmp_folder():
-    """Create temporary folder"""
-    tmpdir = tempfile.mkdtemp()
-    yield tmpdir
-    shutil.rmtree(tmpdir, ignore_errors=True)
-
-
 @pytest.mark.parametrize("type", ["odt", "html"])
 @pytest.mark.parametrize("lang", languages())
 @pytest.mark.parametrize("datefmt", DATE_FORMATS)
-def test_writer(data_folder, tmp_folder, type, lang, datefmt):
+def test_writer(data_folder, type, lang, datefmt):
     input = os.path.join(data_folder, "allged.ged")
-    output = os.path.join(tmp_folder, "output." + type)
-    args, writer = _makeWriter(["-t", type, "-l", lang, "-d", datefmt, input, output])
-    writer.save()
+    with tempfile.TemporaryDirectory() as tmp_folder:
+        output = os.path.join(tmp_folder, "output." + type)
+        rc = main(["-t", type, "-l", lang, "-d", datefmt, input, output])
+        assert rc == 0
