@@ -3,8 +3,6 @@
 """Unit test for utils module
 """
 
-from __future__ import absolute_import, division, print_function
-
 from ged2doc import utils
 from ged4py import model
 
@@ -51,11 +49,11 @@ def test_002_resize():
     assert resized == (10, 5)
 
 
-def test_050_personImageFile():
-    """Test personImageFile method."""
+def test_050_person_image_file():
+    """Test person_image_file method."""
 
     # FORM is subordinate of OBJE
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(2, None, "FORM", "JPG",
                              [], 0, dialect, None).freeze()
     file = model.make_record(
@@ -64,10 +62,10 @@ def test_050_personImageFile():
                              file, form], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file.jpeg"
+    assert utils.person_image_file(person) == "/path/to/file.jpeg"
 
     # FORM is subordinate of FILE
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(3, None, "FORM", "JPG",
                              [], 0, dialect, None).freeze()
     file = model.make_record(
@@ -76,10 +74,10 @@ def test_050_personImageFile():
                              file], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file.jpeg"
+    assert utils.person_image_file(person) == "/path/to/file.jpeg"
 
     # FORM is subordinate of OBJE
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(2, None, "FORM", "WAV",
                              [], 0, dialect, None).freeze()
     file = model.make_record(
@@ -88,10 +86,10 @@ def test_050_personImageFile():
                              file, form], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) is None
+    assert utils.person_image_file(person) is None
 
     # FORM is subordinate of FILE
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(3, None, "FORM", "WAV",
                              [], 0, dialect, None).freeze()
     file = model.make_record(
@@ -100,10 +98,10 @@ def test_050_personImageFile():
                              file], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) is None
+    assert utils.person_image_file(person) is None
 
     # _PRIM flag is set on one of the two OBJE
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(2, None, "FORM", "JPG",
                              [], 0, dialect, None).freeze()
     file = model.make_record(
@@ -120,13 +118,13 @@ def test_050_personImageFile():
                               file, form, prim_y], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje1, obje2], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file_primary.jpg"
+    assert utils.person_image_file(person) == "/path/to/file_primary.jpg"
     person = model.make_record(0, None, "INDI", "", [
                                obje2, obje1], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file_primary.jpg"
+    assert utils.person_image_file(person) == "/path/to/file_primary.jpg"
 
     # multiple FILEs per OBJE, choose JPG over WAV
-    dialect = model.DIALECT_MYHERITAGE
+    dialect = model.Dialect.MYHERITAGE
     form = model.make_record(3, None, "FORM", "JPG",
                              [], 0, dialect, None).freeze()
     file1 = model.make_record(
@@ -139,12 +137,12 @@ def test_050_personImageFile():
                              file1, file2], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file.jpeg"
+    assert utils.person_image_file(person) == "/path/to/file.jpeg"
     obje = model.make_record(1, None, "OBJE", "", [
                              file2, file1], 0, dialect, None).freeze()
     person = model.make_record(0, None, "INDI", "", [
                                obje], 0, dialect, None).freeze()
-    assert utils.personImageFile(person) == "/path/to/file.jpeg"
+    assert utils.person_image_file(person) == "/path/to/file.jpeg"
 
 
 def test_60_embed_ref():
@@ -153,8 +151,8 @@ def test_60_embed_ref():
     eref = utils.embed_ref("id", "name")
     assert eref == "\001person.id\002name\003"
 
-    eref = utils.embed_ref("id", u"Иван Иванович")
-    assert eref == u"\001person.id\002Иван Иванович\003"
+    eref = utils.embed_ref("id", "Иван Иванович")
+    assert eref == "\001person.id\002Иван Иванович\003"
 
 
 def test_61_split_refs():
@@ -164,9 +162,9 @@ def test_61_split_refs():
     items = list(utils.split_refs(text))
     assert items == [("person.id", "name")]
 
-    text = u"\001person.id\002Иван Иванович\003"
+    text = "\001person.id\002Иван Иванович\003"
     items = list(utils.split_refs(text))
-    assert items == [("person.id", u"Иван Иванович")]
+    assert items == [("person.id", "Иван Иванович")]
 
     text = "text before \001person.id\002name\003 text after"
     items = list(utils.split_refs(text))
